# Code128 library's python extension


[![pypi](https://img.shields.io/pypi/v/pycode128.svg)](https://pypi.org/project/pycode128/)
[![python](https://img.shields.io/pypi/pyversions/pycode128.svg)](https://pypi.org/project/pycode128/)
[![Build Status](https://github.com/gpongelli/pycode128/actions/workflows/dev.yml/badge.svg)](https://github.com/gpongelli/pycode128/actions/workflows/dev.yml)
[![codecov](https://codecov.io/gh/gpongelli/pycode128/branch/main/graphs/badge.svg)](https://codecov.io/github/gpongelli/pycode128)



Python extension for Code128 barcode generator library


* Documentation: <https://gpongelli.github.io/pycode128>
* GitHub: <https://github.com/gpongelli/pycode128>
* PyPI: <https://pypi.org/project/pycode128/>
* Free software: MIT


## Features

* TODO

## Credits

This package was created with [Cookiecutter](https://github.com/audreyr/cookiecutter) and the [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage) project template.
